@@ -39,16 +39,15 @@ struct _QuickButton
 {
 	GtkButton __parent;
 
+	char            *name;
+	char            *icon;
+	int              size;
+	
+	guint            dnd_highlight : 1;
+	guint            pressed_timeout;
 	GdkPixbuf       *pixbuf;
 	GdkPixbuf       *scaled;
 	GdkPixbuf       *scaled_bright;
-
-	char            *icon_path;
-	int              size;
-	char            *text;
-	guint            dnd_highlight:1;
-	guint            pressed_timeout;
-
 	GtkIconTheme    *icon_theme;
 };
 
@@ -59,7 +58,7 @@ struct _QuickButtonClass
 	/*< virtual functions >*/
 
 	void (*set_pixmap) (QuickButton *button,
-			    const char  *icon_path,
+			    const char  *icon,
 			    int          size);
 
 	/*< signals >*/
@@ -68,19 +67,15 @@ struct _QuickButtonClass
 };
 
 GType		quick_button_get_type		(void) G_GNUC_CONST;
-
 GtkWidget*	quick_button_new		(const char     *icon_path,
 						 int             size,
 						 const char     *text,
 						 GtkIconTheme   *icon_theme);
-
 void		quick_button_set_pixmap	        (QuickButton    *button,
-						 const char     *icon_path,
+						 const char     *icon,
 						 int             size);
-
 void		quick_button_set_text		(QuickButton    *button,
 						 const char     *text);
-
 void		quick_button_set_dnd_highlight	(QuickButton    *button,
 						 gboolean        highlight);
 
