@@ -25,20 +25,10 @@
 
 #include <glib.h>
 
-
 typedef void (*ErrorFunc)      (gpointer data);
-
 typedef void (*DoneFunc)       (gpointer data);
-
 typedef void (*ProgressFunc)   (gfloat percent, 
 				gpointer data);
 
-typedef void (*AreaReadyFunc)  (guint x,
-				guint y, 
-				guint w, 
-				guint h, 
-				gpointer data);
-
-
 #endif /* TYPEDEFS_H */
 
